@@ -15,7 +15,9 @@
 #' @param k integer: check the kdtree for the\code{k} closest faces (using faces' barycenters.
 #' @param nofPoints integer: number of points per cell in the kd-tree (don't change unless you know what you are doing!)
 #' @param maxDepth integer: depth of the kd-tree (don't change unless you know what you are doing!)
-#' 
+#' @param angdev maximum deviation between reference and target normals. If the none of the k closest triangles match this criterion, the closest point on the closest triangle is returned but the corresponding distance in $quality is set to 1e5.
+#' @param weightnorm logical if angdev is set, this requests the normal of the closest points to be estimated by weighting the surrounding vertex normals. Otherwise, simply the hit face's normal is used (faster but slightly less accurate).
+#' @param ... additional parameters, currently unused.
 #' @return returns an object of class "mesh3d" with:
 #' \item{vb }{4 x n matrix containing n vertices as homolougous coordinates.}
 #' \item{normals }{4 x n matrix containing vertex normals.}
@@ -32,13 +34,16 @@
 #' Distance Fields From Triangle Meshes. Informatics and Mathematical
 #' Modelling.
 #' #' @export
-vcgClostKD <- function(x, mesh,sign=TRUE,barycentric=FALSE, smoothNormals=FALSE, borderchk = FALSE, k = 50,nofPoints = 16, maxDepth = 64) {
-    if (inherits(x,"mesh3d"))
+vcgClostKD <- function(x, mesh,sign=TRUE,barycentric=FALSE, smoothNormals=FALSE, borderchk = FALSE, k = 50,nofPoints = 16, maxDepth = 64,angdev=NULL, weightnorm=FALSE,...) {
+    if (inherits(x,"mesh3d")) {
+        x$it <- x$it-1
         io <- x$vb
+    }
     else if (is.matrix(x) && is.numeric(x)) {
         io <- t(x)
         x <- list()
         x$vb <- io
+        x$it <- NULL
         class(x) <- "mesh3d"
     } else
         stop("x must be a mesh or a matrix")
@@ -48,14 +53,17 @@ vcgClostKD <- function(x, mesh,sign=TRUE,barycentric=FALSE, smoothNormals=FALSE,
     vb <- mesh$vb[1:3,,drop=FALSE]
     it <- (mesh$it-1)
     storage.mode(it) <- "integer"
-    
+    if (is.null(angdev))
+        angdev <- 0
     nofPoints <- as.integer(nofPoints)
     maxDepth <- as.integer(maxDepth)
-    tmp <- .Call("RclosestKD", vb , it, io, as.integer(k[1]),as.logical(sign[1]), as.logical(smoothNormals[1]),as.logical(barycentric[1]),as.logical(borderchk[1]), nofPoints[1],maxDepth[1])
+    tmp <- .Call("RclosestKD", vb , it, io,x$it, as.integer(k[1]),as.logical(sign[1]), as.logical(smoothNormals[1]),as.logical(barycentric[1]),as.logical(borderchk[1]), nofPoints[1],maxDepth[1],angdev,weightnorm)
     x$vb <- rbind(tmp$iomat,1)
     x$normals <- rbind(tmp$normals, 1)
     x$faceptr <- tmp$faceptr+1
     x$quality <- tmp$distance
+    x$angle <- tmp$angle
+    x$it <- x$it+1
     if (barycentric)
         x$barycoords <- tmp$barycoord
     if (borderchk)
